@@ -1,14 +1,11 @@
 #!/usr/bin/python3
 
 import os
-import sys
 import gettext
 import grp
 import locale
-import tempfile
 import subprocess
 import codecs
-import mintcommon
 
 try:
     import configparser
@@ -18,10 +15,9 @@ except ImportError as err:
 import gi
 gi.require_version('Gtk', '3.0')
 gi.require_version('AccountsService', '1.0')
-from gi.repository import GdkX11
-from gi.repository import Gtk, Gio, AccountsService, GLib, GdkPixbuf, XApp
+gi.require_version('XApp', '1.0')
+from gi.repository import Gtk, AccountsService, GLib, GdkPixbuf, XApp
 
-from ImConfig.ImConfig import ImConfig
 
 # Used to detect Debian derivatives (we don't want to show APT features in other distros)
 IS_DEBIAN = os.path.exists("/etc/debian_version")
